# Unfold / Fold

Block extraction (unfold) and block reassembly (fold) operations,
supporting 1D/2D/3D with optional masking and Triton backends.

::: torchlinops.functional.unfold

::: torchlinops.functional.fold

::: torchlinops.functional.array_to_blocks

::: torchlinops.functional.blocks_to_array
